Hover

Trait Hover 

pub trait Hover {
    // Required method
    fn hover(&mut self, cx: &HoverCx) -> Option<HoverInfo>;
}
The provider seam the integrating app implements to answer hover queries.

Required Methods

fn hover(&mut self, cx: &HoverCx) -> Option<HoverInfo>

The doc for the word under the pointer, or None when there is none (or the pointer is not over a word) — the hover popup stays closed.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors